@@ -76,10 +76,8 @@ class TestUndercloud(BaseTestCase):
     @mock.patch('instack_undercloud.undercloud._run_instack')
     @mock.patch('instack_undercloud.undercloud._generate_environment')
     @mock.patch('instack_undercloud.undercloud._load_config')
-    @mock.patch('instack_undercloud.undercloud._die_tuskar_die')
     @mock.patch('instack_undercloud.undercloud._run_validation_groups')
-    def test_install(self, mock_run_validation_groups,
-                     mock_die_tuskar_die, mock_load_config,
+    def test_install(self, mock_run_validation_groups, mock_load_config,
                      mock_generate_environment, mock_run_instack,
                      mock_run_clean_all, mock_run_yum_update, mock_run_orc,
                      mock_post_config, mock_run_command,
@@ -95,7 +93,6 @@ class TestUndercloud(BaseTestCase):
         mock_run_command.assert_called_with(
             ['sudo', 'rm', '-f', '/tmp/svc-map-services'], None, 'rm')
         mock_upgrade_fact.assert_called_with(False)
-        mock_die_tuskar_die.assert_not_called()
         mock_run_validation_groups.assert_not_called()
 
     @mock.patch(
@@ -111,15 +108,19 @@ class TestUndercloud(BaseTestCase):
     @mock.patch('instack_undercloud.undercloud._run_instack')
     @mock.patch('instack_undercloud.undercloud._generate_environment')
     @mock.patch('instack_undercloud.undercloud._load_config')
-    @mock.patch('instack_undercloud.undercloud._die_tuskar_die')
     @mock.patch('instack_undercloud.undercloud._run_validation_groups')
     def test_install_upgrade(self, mock_run_validation_groups,
-                             mock_die_tuskar_die, mock_load_config,
-                             mock_generate_environment, mock_run_instack,
-                             mock_run_yum_clean_all, mock_run_yum_update,
-                             mock_run_orc, mock_post_config, mock_run_command,
+                             mock_load_config,
+                             mock_generate_environment,
+                             mock_run_instack,
+                             mock_run_yum_clean_all,
+                             mock_run_yum_update,
+                             mock_run_orc,
+                             mock_post_config,
+                             mock_run_command,
                              mock_validate_configuration,
-                             mock_configure_logging, mock_upgrade_fact,
+                             mock_configure_logging,
+                             mock_upgrade_fact,
                              mock_load_subnets_config_groups):
         fake_env = mock.MagicMock()
         mock_generate_environment.return_value = fake_env
@@ -131,7 +132,6 @@ class TestUndercloud(BaseTestCase):
         mock_run_command.assert_called_with(
             ['sudo', 'rm', '-f', '/tmp/svc-map-services'], None, 'rm')
         mock_upgrade_fact.assert_called_with(True)
-        mock_die_tuskar_die.assert_called_once()
         mock_run_validation_groups.assert_called_once()
 
     @mock.patch(
@@ -147,10 +147,9 @@ class TestUndercloud(BaseTestCase):
     @mock.patch('instack_undercloud.undercloud._run_instack')
     @mock.patch('instack_undercloud.undercloud._generate_environment')
     @mock.patch('instack_undercloud.undercloud._load_config')
-    @mock.patch('instack_undercloud.undercloud._die_tuskar_die')
     @mock.patch('instack_undercloud.undercloud._run_validation_groups')
     def test_install_upgrade_hieradata(self, mock_run_validation_groups,
-                                       mock_die_tuskar_die, mock_load_config,
+                                       mock_load_config,
                                        mock_generate_environment,
                                        mock_run_instack,
                                        mock_run_yum_clean_all,
@@ -178,7 +177,6 @@ class TestUndercloud(BaseTestCase):
                  '/etc/puppet/hieradata/override.yaml']),
             mock_run_command.mock_calls)
         mock_upgrade_fact.assert_called_with(True)
-        mock_die_tuskar_die.assert_called_once()
         mock_run_validation_groups.assert_called_once()
 
     @mock.patch('instack_undercloud.undercloud._configure_logging')
@@ -215,10 +213,10 @@ class TestUndercloud(BaseTestCase):
     def test_extract_from_stackrc(self):
         with open(os.path.expanduser('~/stackrc'), 'w') as f:
             f.write('OS_USERNAME=aturing\n')
-            f.write('OS_AUTH_URL=http://bletchley:5000/\n')
+            f.write('OS_AUTH_URL=https://bletchley:5000/\n')
         self.assertEqual('aturing',
                          undercloud._extract_from_stackrc('OS_USERNAME'))
-        self.assertEqual('http://bletchley:5000/',
+        self.assertEqual('https://bletchley:5000/',
                          undercloud._extract_from_stackrc('OS_AUTH_URL'))
 
     @mock.patch('instack_undercloud.undercloud._check_hostname')
@@ -273,8 +271,7 @@ class TestCheckHostname(BaseTestCase):
             undercloud._check_hostname()
             mock_run_command.assert_called_with([
                 'sudo', '/bin/bash', '-c',
-                'sed -i "s/127.0.0.1\\(\\s*\\)/'
-                '127.0.0.1\\1test.hostname test /" '
+                'sed -i "s/127.0.0.1\(\s*\)/127.0.0.1\\1test.hostname test /" '
                 '/etc/hosts'],
                 name='hostname-to-etc-hosts')
 
@@ -291,8 +288,7 @@ class TestCheckHostname(BaseTestCase):
             undercloud._check_hostname()
             mock_run_command.assert_called_with([
                 'sudo', '/bin/bash', '-c',
-                'sed -i "s/127.0.0.1\\(\\s*\\)/'
-                '127.0.0.1\\1test.hostname test /" '
+                'sed -i "s/127.0.0.1\(\s*\)/127.0.0.1\\1test.hostname test /" '
                 '/etc/hosts'],
                 name='hostname-to-etc-hosts')
 
@@ -309,7 +305,7 @@ class TestCheckHostname(BaseTestCase):
             undercloud._check_hostname()
         mock_run_command.assert_called_with([
             'sudo', '/bin/bash', '-c',
-            'sed -i "s/127.0.0.1\\(\\s*\\)/'
+            'sed -i "s/127.0.0.1\(\s*\)/'
             '127.0.0.1\\1test-hostname.domain test-hostname /" '
             '/etc/hosts'],
             name='hostname-to-etc-hosts')
@@ -587,28 +583,20 @@ class TestGenerateEnvironment(BaseTestCase):
         self.assertEqual('http://foo/bar',
                          env['DOCKER_REGISTRY_MIRROR'])
 
-    def test_docker_insecure_registries(self):
-        self.conf.config(docker_insecure_registries=['http://foo/bar:8787'])
-        env = undercloud._generate_environment('.')
-        insecure_registries = json.loads(env['DOCKER_INSECURE_REGISTRIES'])
-        # Spot check one service
-        self.assertEqual(['192.168.24.1:8787', '192.168.24.3:8787',
-                         'http://foo/bar:8787'], insecure_registries)
-
     def test_generate_endpoints(self):
         env = undercloud._generate_environment('.')
         endpoint_vars = {k: v for (k, v) in env.items()
                          if k.startswith('UNDERCLOUD_ENDPOINT')}
         self.assertEqual(96, len(endpoint_vars))
         # Spot check one service
-        self.assertEqual('http://192.168.24.1:5000',
+        self.assertEqual('https://192.168.24.2:13000',
                          env['UNDERCLOUD_ENDPOINT_KEYSTONE_PUBLIC'])
-        self.assertEqual('http://192.168.24.1:5000',
+        self.assertEqual('http://192.168.24.3:5000',
                          env['UNDERCLOUD_ENDPOINT_KEYSTONE_INTERNAL'])
-        self.assertEqual('http://192.168.24.1:35357',
+        self.assertEqual('http://192.168.24.3:35357',
                          env['UNDERCLOUD_ENDPOINT_KEYSTONE_ADMIN'])
         # Also check that the tenant id part is preserved
-        self.assertEqual('http://192.168.24.1:8080/v1/AUTH_%(tenant_id)s',
+        self.assertEqual('https://192.168.24.2:13808/v1/AUTH_%(tenant_id)s',
                          env['UNDERCLOUD_ENDPOINT_SWIFT_PUBLIC'])
 
     def test_generate_endpoints_ssl_manual(self):
@@ -627,18 +615,18 @@ class TestGenerateEnvironment(BaseTestCase):
         self.assertEqual('https://192.168.24.2:13808/v1/AUTH_%(tenant_id)s',
                          env['UNDERCLOUD_ENDPOINT_SWIFT_PUBLIC'])
 
-    def test_generate_endpoints_ssl_auto(self):
-        self.conf.config(generate_service_certificate=True)
+    def test_generate_endpoints_ssl_off(self):
+        self.conf.config(generate_service_certificate=False)
         env = undercloud._generate_environment('.')
         # Spot check one service
-        self.assertEqual('https://192.168.24.2:13000',
+        self.assertEqual('http://192.168.24.1:5000',
                          env['UNDERCLOUD_ENDPOINT_KEYSTONE_PUBLIC'])
-        self.assertEqual('http://192.168.24.3:5000',
+        self.assertEqual('http://192.168.24.1:5000',
                          env['UNDERCLOUD_ENDPOINT_KEYSTONE_INTERNAL'])
-        self.assertEqual('http://192.168.24.3:35357',
+        self.assertEqual('http://192.168.24.1:35357',
                          env['UNDERCLOUD_ENDPOINT_KEYSTONE_ADMIN'])
         # Also check that the tenant id part is preserved
-        self.assertEqual('https://192.168.24.2:13808/v1/AUTH_%(tenant_id)s',
+        self.assertEqual('http://192.168.24.1:8080/v1/AUTH_%(tenant_id)s',
                          env['UNDERCLOUD_ENDPOINT_SWIFT_PUBLIC'])
 
     def test_absolute_cert_path(self):
@@ -662,6 +650,12 @@ class TestGenerateEnvironment(BaseTestCase):
             os.chdir(cur_dir)
 
     def test_no_cert_path(self):
+        env = undercloud._generate_environment('.')
+        self.assertEqual('/etc/pki/tls/certs/undercloud-192.168.24.2.pem',
+                         env['UNDERCLOUD_SERVICE_CERTIFICATE'])
+
+    def test_no_ssl(self):
+        self.conf.config(generate_service_certificate=False)
         env = undercloud._generate_environment('.')
         self.assertEqual('', env['UNDERCLOUD_SERVICE_CERTIFICATE'])
 
@@ -1006,12 +1000,7 @@ class TestPostConfig(BaseTestCase):
     @mock.patch('instack_undercloud.undercloud._get_auth_values')
     @mock.patch('instack_undercloud.undercloud._get_session')
     @mock.patch('mistralclient.api.client.client', autospec=True)
-    @mock.patch('swiftclient.client.Connection', autospec=True)
-    @mock.patch('os_client_config.make_client')
-    def test_run_validation_groups_success(self,
-                                           mock_make_client,
-                                           mock_swift_client,
-                                           mock_mistral_client,
+    def test_run_validation_groups_success(self, mock_mistral_client,
                                            mock_get_session,
                                            mock_auth_values):
         mock_mistral = mock.Mock()
@@ -1019,76 +1008,19 @@ class TestPostConfig(BaseTestCase):
         mock_mistral.environments.list.return_value = []
         mock_mistral.executions.get.return_value = mock.Mock(state="SUCCESS")
         mock_get_session.return_value = mock.MagicMock()
-
-        mock_auth_values.return_value = ('aturing', '3nigma', 'hut8',
-                                         'http://bletchley:5000/')
-
-        mock_instance_swift = mock.Mock()
-        mock_instance_swift.get_account.return_value = [None,
-                                                        [{'name': 'hut8'},
-                                                         {'name': 'mystack'}]]
-        mock_swift_client.return_value = mock_instance_swift
-
-        mock_heat = mock.Mock()
-        aux_stack = mock.Mock()
-        aux_stack.stack_name = "mystack"
-        mock_heat.stacks.list.return_value = [aux_stack]
-        mock_make_client.return_value = mock_heat
-
         undercloud._run_validation_groups(["post-upgrade"])
         mock_mistral.executions.create.assert_called_once_with(
             'tripleo.validations.v1.run_groups',
             workflow_input={
                 'group_names': ['post-upgrade'],
-                'plan': 'mystack',
             }
         )
 
-    @mock.patch('instack_undercloud.undercloud._get_auth_values')
-    @mock.patch('instack_undercloud.undercloud._get_session')
-    @mock.patch('mistralclient.api.client.client', autospec=True)
-    @mock.patch('swiftclient.client.Connection', autospec=True)
-    @mock.patch('os_client_config.make_client')
-    def test_run_validation_groups_no_overcloud(self,
-                                                mock_make_client,
-                                                mock_swift_client,
-                                                mock_mistral_client,
-                                                mock_get_session,
-                                                mock_auth_values):
-        mock_mistral = mock.Mock()
-        mock_mistral_client.return_value = mock_mistral
-        mock_mistral.environments.list.return_value = []
-        mock_mistral.executions.get.return_value = mock.Mock(state="SUCCESS")
-        mock_get_session.return_value = mock.MagicMock()
-
-        mock_auth_values.return_value = ('aturing', '3nigma', 'hut8',
-                                         'http://bletchley:5000/')
-
-        mock_instance_swift = mock.Mock()
-        mock_instance_swift.get_account.return_value = [None,
-                                                        [{'name': 'hut8'},
-                                                         {'name': 'mystack'}]]
-        mock_swift_client.return_value = mock_instance_swift
-
-        mock_heat = mock.Mock()
-        aux_stack = mock.Mock()
-        aux_stack.stack_name = "mystackooo"
-        mock_heat.stacks.list.return_value = [aux_stack]
-        mock_make_client.return_value = mock_heat
-
-        undercloud._run_validation_groups(["post-upgrade"])
-        mock_mistral.executions.create.assert_not_called()
-
     @mock.patch('instack_undercloud.undercloud._get_auth_values')
     @mock.patch('instack_undercloud.undercloud._get_session')
     @mock.patch('mistralclient.api.client.client', autospec=True)
     @mock.patch('time.strptime')
-    @mock.patch('swiftclient.client.Connection', autospec=True)
-    @mock.patch('os_client_config.make_client')
-    def test_run_validation_groups_fail(self,
-                                        mock_make_client,
-                                        mock_swift_client,
-                                        mock_strptime,
+    def test_run_validation_groups_fail(self, mock_strptime,
                                         mock_mistral_client, mock_get_session,
                                         mock_auth_values):
         mock_mistral = mock.Mock()
@@ -1097,23 +1029,7 @@ class TestPostConfig(BaseTestCase):
         mock_mistral.executions.get.return_value = mock.Mock(state="FAIL")
         mock_mistral.executions.get_output.return_value = "ERROR!"
         mock_mistral.executions.get.id = "1234"
-        mock_mistral.action_executions.find.return_value = []
-
-        mock_auth_values.return_value = ('aturing', '3nigma', 'hut8',
-                                         'http://bletchley:5000/')
-
-        mock_instance_swift = mock.Mock()
-        mock_instance_swift.get_account.return_value = [None,
-                                                        [{'name': 'hut8'},
-                                                         {'name': 'mystack'}]]
-        mock_swift_client.return_value = mock_instance_swift
-
-        mock_heat = mock.Mock()
-        aux_stack = mock.Mock()
-        aux_stack.stack_name = "mystack"
-        mock_heat.stacks.list.return_value = [aux_stack]
-        mock_make_client.return_value = mock_heat
-
+        mock_mistral.action_executions.list.return_value = []
         mock_strptime.return_value = time.mktime(time.localtime())
         mock_get_session.return_value = mock.MagicMock()
         self.assertRaises(
@@ -1124,36 +1040,15 @@ class TestPostConfig(BaseTestCase):
     @mock.patch('instack_undercloud.undercloud._get_session')
     @mock.patch('mistralclient.api.client.client', autospec=True)
     @mock.patch('time.strptime')
-    @mock.patch('swiftclient.client.Connection', autospec=True)
-    @mock.patch('os_client_config.make_client')
-    def test_run_validation_groups_timeout(self,
-                                           mock_make_client,
-                                           mock_swift_client,
-                                           mock_strptime,
+    def test_run_validation_groups_timeout(self, mock_strptime,
                                            mock_mistral_client,
                                            mock_get_session, mock_auth_values):
         mock_mistral = mock.Mock()
         mock_mistral_client.return_value = mock_mistral
         mock_mistral.environments.list.return_value = []
         mock_mistral.executions.get.id = "1234"
-        mock_mistral.action_executions.find.return_value = []
-        mock_instance_swift = mock.Mock()
-
-        mock_auth_values.return_value = ('aturing', '3nigma', 'hut8',
-                                         'http://bletchley:5000/')
-
-        mock_instance_swift = mock.Mock()
-        mock_instance_swift.get_account.return_value = [None,
-                                                        [{'name': 'hut8'},
-                                                         {'name': 'mystack'}]]
-        mock_swift_client.return_value = mock_instance_swift
-
-        mock_heat = mock.Mock()
-        aux_stack = mock.Mock()
-        aux_stack.stack_name = "mystack"
-        mock_heat.stacks.list.return_value = [aux_stack]
-        mock_make_client.return_value = mock_heat
-
+        mock_mistral.action_executions.list.return_value = []
+        mock_get_session.return_value = mock.MagicMock()
         mock_time = mock.MagicMock()
         mock_time.return_value = time.mktime(time.localtime())
         mock_strptime.return_value = time.mktime(time.localtime())
@@ -1173,7 +1068,6 @@ class TestPostConfig(BaseTestCase):
             'tripleo.plan_management.v1.create_deployment_plan',
             workflow_input={
                 'container': 'overcloud',
-                'queue_name': mock.ANY,
                 'use_default_templates': True,
             }
         )
@@ -1249,7 +1143,7 @@ class TestPostConfig(BaseTestCase):
     def test_create_default_plan_failed(self, mock_strptime):
         mock_mistral = mock.Mock()
         mock_mistral.executions.get.return_value = mock.Mock(state="ERROR")
-        mock_mistral.action_executions.find.return_value = []
+        mock_mistral.action_executions.list.return_value = []
         mock_strptime.return_value = time.mktime(time.localtime())
         self.assertRaises(
             RuntimeError,
@@ -1463,55 +1357,8 @@ class TestPostConfig(BaseTestCase):
     @mock.patch('instack_undercloud.undercloud._create_mistral_config_'
                 'environment')
     @mock.patch('instack_undercloud.undercloud._create_default_plan')
-    def test_post_config_mistral(self, mock_create, mock_cmce, mock_listdir,
-                                 mock_isfile):
-        instack_env = {}
-        mock_mistral = mock.Mock()
-        mock_swift = mock.Mock()
-        mock_swift.get_account.return_value = [None, [{'name': 'hut8'}]]
-
-        mock_workbooks = [mock.Mock() for m in range(2)]
-        mock_workbooks[0].name = 'foo'
-        mock_workbooks[1].name = 'tripleo.bar'
-        mock_mistral.workbooks.list.return_value = mock_workbooks
-
-        mock_triggers = [mock.Mock() for m in range(2)]
-        mock_triggers[0].name = 'foobar'
-        mock_triggers[0].workflow_name = 'foo'
-        mock_triggers[1].name = 'delete_me'
-        mock_triggers[1].workflow_name = 'tripleo.bar'
-        mock_mistral.cron_triggers.list.return_value = mock_triggers
-
-        mock_workflows = [mock.Mock() for m in range(2)]
-        mock_workflows[0].name = 'foo'
-        mock_workflows[1].name = 'tripleo.bar'
-        mock_workflows[0].tags = []
-        mock_workflows[1].tags = []
-        mock_mistral.workflows.list.return_value = mock_workflows
-        mock_listdir.return_value = ['foo.yaml', 'bar.yaml']
-        undercloud._post_config_mistral(instack_env, mock_mistral, mock_swift)
-        self.assertEqual([mock.call('tripleo.bar')],
-                         mock_mistral.workbooks.delete.mock_calls)
-        self.assertEqual([mock.call('tripleo.bar')],
-                         mock_mistral.workflows.delete.mock_calls)
-        self.assertEqual([mock.call('delete_me')],
-                         mock_mistral.cron_triggers.delete.mock_calls)
-        self.assertEqual([mock.call(undercloud.PATHS.WORKBOOK_PATH +
-                                    '/foo.yaml'),
-                         mock.call(undercloud.PATHS.WORKBOOK_PATH +
-                                   '/bar.yaml')],
-                         mock_mistral.workbooks.create.mock_calls)
-        mock_cmce.assert_called_once_with(instack_env, mock_mistral)
-        mock_create.assert_called_once_with(mock_mistral, ['hut8'],
-                                            timeout=1200)
-
-    @mock.patch('os.path.isfile', return_value=True)
-    @mock.patch('os.listdir')
-    @mock.patch('instack_undercloud.undercloud._create_mistral_config_'
-                'environment')
-    @mock.patch('instack_undercloud.undercloud._create_default_plan')
-    def test_post_config_mistral_with_tags(self, mock_create, mock_cmce,
-                                           mock_listdir, mock_isfile):
+    def test_post_config_mistral(self, mock_create, mock_cmce,
+                                 mock_listdir, mock_isfile):
         instack_env = {}
         mock_mistral = mock.Mock()
         mock_swift = mock.Mock()
@@ -1548,8 +1395,7 @@ class TestPostConfig(BaseTestCase):
                                    '/bar.yaml')],
                          mock_mistral.workbooks.create.mock_calls)
         mock_cmce.assert_called_once_with(instack_env, mock_mistral)
-        mock_create.assert_called_once_with(mock_mistral, ['hut8'],
-                                            timeout=1200)
+        mock_create.assert_called_once_with(mock_mistral, ['hut8'])
 
     def _neutron_mocks(self):
         mock_sdk = mock.MagicMock()
