@@ -210,7 +210,7 @@ _opts = [
                      'OpenStack API endpoints, leaving it unset disables SSL.')
                ),
     cfg.BoolOpt('generate_service_certificate',
-                default=False,
+                default=True,
                 help=('When set to True, an SSL certificate will be generated '
                       'as part of the undercloud install and this certificate '
                       'will be used in place of the value for '
@@ -294,11 +294,6 @@ _opts = [
                 help=('Whether to run benchmarks when inspecting nodes. '
                       'Requires inspection_extras set to True.')
                 ),
-    cfg.BoolOpt('inspection_enable_uefi',
-                default=True,
-                help=('Whether to support introspection of nodes that have '
-                      'UEFI-only firmware.')
-                ),
     cfg.BoolOpt('enable_node_discovery',
                 default=False,
                 help=('Makes ironic-inspector enroll any unknown node that '
@@ -1460,11 +1455,7 @@ def _generate_environment(instack_root):
 
     _write_password_file(instack_env)
 
-    if CONF.generate_service_certificate:
-        public_host = CONF.undercloud_public_host
-        instack_env['UNDERCLOUD_SERVICE_CERTIFICATE'] = (
-            '/etc/pki/tls/certs/undercloud-%s.pem' % public_host)
-    elif instack_env['UNDERCLOUD_SERVICE_CERTIFICATE']:
+    if instack_env['UNDERCLOUD_SERVICE_CERTIFICATE']:
         raw_value = instack_env['UNDERCLOUD_SERVICE_CERTIFICATE']
         abs_cert = os.path.abspath(raw_value)
         if abs_cert != raw_value:
@@ -1477,6 +1468,10 @@ def _generate_environment(instack_root):
             else:
                 instack_env['UNDERCLOUD_SERVICE_CERTIFICATE'] = os.path.join(
                     home_dir, raw_value)
+    elif CONF.generate_service_certificate:
+        public_host = CONF.undercloud_public_host
+        instack_env['UNDERCLOUD_SERVICE_CERTIFICATE'] = (
+            '/etc/pki/tls/certs/undercloud-%s.pem' % public_host)
 
     return instack_env
 
@@ -1882,7 +1877,6 @@ def _run_validation_groups(groups=[], mistral_url='', timeout=540,
 
 def _create_default_plan(mistral, plans, timeout=360):
     plan_name = 'overcloud'
-    queue_name = str(uuid.uuid4())
 
     if plan_name in plans:
         LOG.info('Not creating default plan "%s" because it already exists.',
@@ -1893,7 +1887,6 @@ def _create_default_plan(mistral, plans, timeout=360):
         'tripleo.plan_management.v1.create_deployment_plan',
         workflow_input={
             'container': plan_name,
-            'queue_name': queue_name,
             'use_default_templates': True,
         }
     )
@@ -1929,21 +1922,8 @@ def _post_config_mistral(instack_env, mistral, swift):
     managed_tag = 'tripleo-common-managed'
 
     all_workflows = mistral.workflows.list()
-    workflow_tags = set()
-    for workflow in all_workflows:
-        workflow_tags.update(workflow.tags)
-
-    # If at least one workflow is tagged, then we should only delete those.
-    # Otherwise we should revert to the previous behaviour - this is required
-    # for the initial upgrade.
-    # TODO(d0ugal): From Q onwards we should only ever delete workflows with
-    # the tripleo-common tag.
-    if 'tripleo-common-managed' in workflow_tags:
-        workflows_delete = [w.name for w in all_workflows
-                            if managed_tag in w.tags]
-    else:
-        workflows_delete = [w.name for w in all_workflows
-                            if w.name.startswith('tripleo')]
+    workflows_delete = [w.name for w in all_workflows
+                        if managed_tag in w.tags]
 
     # in order to delete workflows they should have no triggers associated
     for trigger in [t for t in mistral.cron_triggers.list()
@@ -2178,9 +2158,9 @@ def _config_neutron_segments_and_subnets(sdk, ctlplane_id):
     s = CONF.get(CONF.local_subnet)
     subnet = _get_subnet(sdk, s.cidr, ctlplane_id)
     if subnet and not subnet.segment_id:
-        LOG.warn("Local subnet %s already exists and is not associated with a "
-                 "network segment. Any additional subnets will be ignored.",
-                 CONF.local_subnet)
+        LOG.warning("Local subnet %s already exists and is not associated "
+                    "with a network segment. Any additional subnets will "
+                    "be ignored.", CONF.local_subnet)
         host_routes = [{'destination': '169.254.169.254/32',
                         'nexthop': str(netaddr.IPNetwork(CONF.local_ip).ip)}]
         allocation_pool = [{'start': s.dhcp_start, 'end': s.dhcp_end}]
@@ -2277,18 +2257,6 @@ def _handle_upgrade_fact(upgrade=False):
         _run_command(['sudo', 'chmod', '0644', fact_path])
 
 
-def _die_tuskar_die():
-    """Remove tuskar* packages
-
-    Make sure to remove tuskar https://bugs.launchpad.net/tripleo/+bug/1691744
-    # openstack-[tuskar, tuskar-ui, tuskar-ui-extras] & python-tuskarclient
-    """
-    try:
-        _run_command(['sudo', 'yum', 'remove', '-y', '*tuskar*'])
-    except subprocess.CalledProcessError as e:
-        LOG.error('Error with tuskar removal task %s - continuing', e.output)
-
-
 def install(instack_root, upgrade=False):
     """Install the undercloud
 
@@ -2301,25 +2269,12 @@ def install(instack_root, upgrade=False):
         LOG.info('Logging to %s', PATHS.LOG_FILE)
         _load_config()
         _load_subnets_config_groups()
-        # Since 'subnets' parameter in opts is used to dynamically
-        # add per network groups, re-load config.
-        _load_config()
         _clean_os_refresh_config()
         _clean_os_collect_config()
         _validate_configuration()
         instack_env = _generate_environment(instack_root)
         _generate_init_data(instack_env)
         ovs_interfaces = _get_ovs_interfaces()
-        if upgrade:
-            # Even if we backport https://review.openstack.org/#/c/457478/
-            # into stable branches of puppet-ironic, we still need a way
-            # to handle existing deployments.
-            # This task will fix ironic-dbsync.log ownership on existing
-            # deployments during an upgrade. It can be removed after we
-            # release Pike.
-            _run_command(['sudo', '/usr/bin/chown', 'ironic:ironic',
-                          '/var/log/ironic/ironic-dbsync.log'])
-            _die_tuskar_die()
         if CONF.undercloud_update_packages:
             _run_yum_clean_all(instack_env)
             if ovs_interfaces:
